# TorrentFile

## Version 0.1.3

### Added

    - Created sub-commands for the cli interface
    - Created edit torrent capabilities
    - Created edit sub-command for cli
    - Added interactive mode 
    - Added -i flag for CLI to invoke interactive mode
    - Added full set of tests for interactive and editing

----------------

## Version 0.1.2

### Updated / Fixed

    - Package documentation has been updated to a new look and smoother layout.
    - Fixed bug with the logging output functionality.
    - Improved logging in general with new notifications and more output for -d flag
    - Additional tests added for logging.

----------------

## Version 0.1.1

### Fixed

    - Recheck output bug

### Updated

    - Documentation improvements and fixes

----------------

## Version 0.1.0

### Fixed

    - Documentation updates and minor bug fixes

### Feature

    - Including web-seed urls to torrent file info during file creation

### Added

    - CLI argument for adding web-seed urls to torrent file

----------------

## Version 0.0.2

### Added

    - Full testing suite with 100% coverage

### Fixed/Improved

    - Rechecking procedure and output

----------------

## Version 0.0.1

    - New Project based off of torrentfile-legacy
